==> wilmar-in-domain-0.0.122-sources.jar: com/xforceplus/wilmar/entity/InvoiceMain.java <==
package com.xforceplus.wilmar.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-12
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceMain implements Serializable {

  private static final long serialVersionUID=1L;

  private String invoiceId;

  private String invoiceType;

  private String invoiceNo;

  private String invoiceCode;

  private String sellerTaxNo;

  private String sellerName;

  private String sellerAddrTel;

  private String sellerAddress;

  private String sellerTel;

  private String sellerBankInfo;

  private String sellerBankName;

  private String sellerBankAccount;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserAddrTel;

  private String purchaserAddress;

  private String purchaserTel;

  private String purchaserBankInfo;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private LocalDateTime paperDrewDate;

  private String remark;

  private String cashierName;

  private String checkerName;

  private String invoicerName;

  private String status;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String redNotificationNo;

  private String sellerNo;

  private String purchaserNo;

  private String imageUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String bookkeepingStatus;

  private String identifyStatus;

  private String salesbillNo;

  private String invoiceAllocationStatus;

  private Long sellerId;

  private Long purchaserId;

  private String taxRate;

  private String tenantCode;

  private String specialInvoiceFlag;

  private String orderNo;

  private String customerNo;

  private String currencyType;

  private String purchaserCode;

  private String sellerCode;

  private String invoiceSheet;

  private String imageId;

  private String invoiceUrl;

  private String systemSource;

  private String invoiceStatusType;

  private String deductionInvoiceUrl;

  private String postingDate;

  private String invoiceCategory;

  private Long redFlag;

  private String replaceInvoiceId;

  private String businessType;

  private String machineCode;

  private String checkCode;

  private String cipherText;

  private String authSyncStatus;

  private String authResponseTime;

  private String authRequestTime;

  private String authTaxPeriod;

  private String checkTime;

  private String authUse;

  private String calculateMark;

  private String imageToExist;

  private String billCode;

  private String serialNumber;




        }

==> wilmar-in-domain-0.0.172-sources.jar: com/xforceplus/wilmar/entity/InvoiceMain.java <==
package com.xforceplus.wilmar.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-27
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceMain implements Serializable {

  private static final long serialVersionUID=1L;

  private String invoiceId;

  private String invoiceType;

  private String invoiceNo;

  private String invoiceCode;

  private String sellerTaxNo;

  private String sellerName;

  private String sellerAddrTel;

  private String sellerAddress;

  private String sellerTel;

  private String sellerBankInfo;

  private String sellerBankName;

  private String sellerBankAccount;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserAddrTel;

  private String purchaserAddress;

  private String purchaserTel;

  private String purchaserBankInfo;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private LocalDateTime paperDrewDate;

  private String remark;

  private String cashierName;

  private String checkerName;

  private String invoicerName;

  private String status;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String redNotificationNo;

  private String sellerNo;

  private String purchaserNo;

  private String imageUrl;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String bookkeepingStatus;

  private String identifyStatus;

  private String salesbillNo;

  private String invoiceAllocationStatus;

  private Long sellerId;

  private Long purchaserId;

  private String taxRate;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  private String specialInvoiceFlag;

  private String orderNo;

  private String customerNo;

  private String currencyType;

  private String purchaserCode;

  private String sellerCode;

  private String invoiceSheet;

  private String imageId;

  private String invoiceUrl;

  private String systemSource;

  private String invoiceStatusType;

  private String deductionInvoiceUrl;

  private LocalDateTime postingDate;

  private String invoiceCategory;

  private String replaceInvoiceId;

  private String businessType;

  private String machineCode;

  private String checkCode;

  private String cipherText;

  private String authSyncStatus;

  private LocalDateTime authResponseTime;

  private LocalDateTime authRequestTime;

  private LocalDateTime authTaxPeriod;

  private LocalDateTime checkTime;

  private String authUse;

  private String calculateMark;

  private String imageToExist;

  private String billCode;

  private String serialNumber;

  private String identifyFlag;

  private String invoiceOrigin;

  private String earlyWarning;

  private BigDecimal effectiveTaxAmount;

  private LocalDateTime authSyncTime;

  private String redFlag;




        }
